@@ -87,11 +87,11 @@ void  RBBITableBuilder::build() {
 #endif
 
     //
-    // If the rules contained any references to {bof} 
+    // If the rules contained any references to {bof}
     //   add a {bof} <cat> <former root of tree> to the
-    //   tree.  Means that all matches must start out with the 
+    //   tree.  Means that all matches must start out with the
     //   {bof} fake character.
-    // 
+    //
     if (fRB->fSetBuilder->sawBOF()) {
         RBBINode *bofTop    = new RBBINode(RBBINode::opCat);
         RBBINode *bofLeaf   = new RBBINode(RBBINode::leafChar);
@@ -424,9 +424,9 @@ void RBBITableBuilder::calcChainedFollowPos(RBBINode *tree) {
     }
 
     // Collect all leaf nodes that can start matches for rules
-    // with inbound chaining enabled, which is the union of the 
+    // with inbound chaining enabled, which is the union of the
     // firstPosition sets from each of the rule root nodes.
-    
+
     UVector ruleRootNodes(*fStatus);
     addRuleRootNodes(&ruleRootNodes, tree);
 
@@ -537,7 +537,7 @@ void RBBITableBuilder::bofFixup() {
     //  (excluding the fake bofNode)
     //  We want the nodes that can start a match in the
     //     part labeled "rest of tree"
-    // 
+    //
     UVector *matchStartNodes = fTree->fLeftChild->fRightChild->fFirstPosSet;
 
     RBBINode *startNode;
@@ -553,7 +553,7 @@ void RBBITableBuilder::bofFixup() {
             //    explicitly written into a rule.
             //  Add everything from the followPos set of this node to the
             //    followPos set of the fake bofNode at the start of the tree.
-            //  
+            //
             setAdd(bofNode->fFollowPos, startNode->fFollowPos);
         }
     }
@@ -574,7 +574,7 @@ void RBBITableBuilder::buildStateTable() {
     }
     RBBIStateDescriptor *failState;
     // Set it to NULL to avoid uninitialized warning
-    RBBIStateDescriptor *initialState = NULL; 
+    RBBIStateDescriptor *initialState = NULL;
     //
     // Add a dummy state 0 - the stop state.  Not from Aho.
     int      lastInputSymbol = fRB->fSetBuilder->getNumCharCategories() - 1;
@@ -1085,8 +1085,8 @@ bool RBBITableBuilder::findDuplCharClassFrom(int32_t &baseCategory, int32_t &dup
     int32_t numStates = fDStates->size();
     int32_t numCols = fRB->fSetBuilder->getNumCharCategories();
 
-    uint16_t table_base;
-    uint16_t table_dupl;
+    uint16_t table_base = 0;
+    uint16_t table_dupl = 0;
     for (; baseCategory < numCols-1; ++baseCategory) {
         for (duplCategory=baseCategory+1; duplCategory < numCols; ++duplCategory) {
              for (int32_t state=0; state<numStates; state++) {
