@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' package for R.
- * Copyright (C) 2013-2016, Marek Gagolewski and Bartek Tartanus
+ * Copyright (c) 2013-2017, Marek Gagolewski and other contributors.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -45,21 +45,26 @@
  * A class to manage a break iterator's options
  *
  * @version 0.4-1 (Marek Gagolewski, 2014-12-02)
+ *
+ * @version 1.1.3 (Marek Gagolewski, 2017-01-07) UBRK_COUNT deprecated
+ *
+ * @version 1.1.6 (Marek Gagolewski, 2017-04-22) Add support for RBBI
  */
 class StriBrkIterOptions {
    protected:
 
-      const char* locale; // R_alloc'd
+      const char* locale;      // R_alloc'd
+      UnicodeString rules;
       UBreakIteratorType type;
-      int32_t* skip_rules; // R_alloc'd
-      R_len_t  skip_size; // number of elements in skip_rules
+      int32_t* skip_rules;     // R_alloc'd
+      R_len_t  skip_size;      // number of elements in skip_rules
 
 
    private:
 
       void setEmptyOpts() {
          locale = NULL;
-         type = UBRK_COUNT;
+         type = UBRK_CHARACTER;
          skip_rules = NULL;
          skip_size = 0;
       }
@@ -90,8 +95,11 @@ class StriBrkIterOptions {
  *
  * @version 0.3-1 (Marek Gagolewski, 2014-10-30)
  *
- * @version 0.4-1 (Marek Gagolewski, 2014-12-02)
- * separate class
+ * @version 0.4-1 (Marek Gagolewski, 2014-12-02) separate class
+ *
+ * @version 1.1.3 (Marek Gagolewski, 2017-01-07) UBRK_COUNT deprecated
+ *
+ * @version 1.1.6 (Marek Gagolewski, 2017-04-22) Add support for RBBI
  */
 class StriUBreakIterator : public StriBrkIterOptions {
    private:
@@ -103,11 +111,18 @@ class StriUBreakIterator : public StriBrkIterOptions {
          if (uiterator) throw StriException("!NDEBUG: StriUBreakIterator::open()");
 #endif
          UErrorCode status = U_ZERO_ERROR;
-         switch (type) {
-            case UBRK_CHARACTER: // character [this is not documented]
+         if (!rules.isEmpty()) {
+            UParseError parseErr;
+            uiterator = ubrk_openRules(rules.getTerminatedBuffer(),
+                                       -1/*null-terminated*/, NULL, 0,
+                                       &parseErr, &status);
+         }
+         else {
+            switch (type) {
+            case UBRK_CHARACTER: // character
                uiterator = ubrk_open(UBRK_CHARACTER, locale, NULL, 0, &status);
                break;
-            case UBRK_LINE: // line_break [this is not documented]
+            case UBRK_LINE: // line_break
                uiterator = ubrk_open(UBRK_LINE, locale, NULL, 0, &status);
                break;
             case UBRK_SENTENCE: // sentence
@@ -116,9 +131,9 @@ class StriUBreakIterator : public StriBrkIterOptions {
             case UBRK_WORD: // word
                uiterator = ubrk_open(UBRK_WORD, locale, NULL, 0, &status);
                break;
-            case UBRK_COUNT:
             default:
                throw StriException(MSG__INTERNAL_ERROR);
+            }
          }
          STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
       }
@@ -177,11 +192,13 @@ class StriUBreakIterator : public StriBrkIterOptions {
  *
  * @version 0.4-1 (Marek Gagolewski, 2014-12-02)
  * separate class
+ *
+ * @version 1.1.6 (Marek Gagolewski, 2017-04-22) Add support for RBBI
  */
 class StriRuleBasedBreakIterator : public StriBrkIterOptions {
    private:
 
-      RuleBasedBreakIterator* rbiterator;
+      BreakIterator* rbiterator;
       UText* searchText;
       R_len_t searchPos; // may be BreakIterator::DONE
       const char* searchStr; // owned by caller
@@ -198,29 +215,31 @@ class StriRuleBasedBreakIterator : public StriBrkIterOptions {
       void open() {
          UErrorCode status = U_ZERO_ERROR;
          Locale loc = Locale::createFromName(locale);
-         switch (type) {
+         if (!rules.isEmpty()) {
+            UParseError parseErr;
+            rbiterator = (BreakIterator*) new RuleBasedBreakIterator(
+               UnicodeString(rules), parseErr, status
+            );
+         }
+         else {
+            switch (type) {
             case UBRK_CHARACTER: // character
-               rbiterator = (RuleBasedBreakIterator*)BreakIterator::createCharacterInstance(loc, status);
+               rbiterator = (BreakIterator*)BreakIterator::createCharacterInstance(loc, status);
                break;
             case UBRK_LINE: // line_break
-               rbiterator = (RuleBasedBreakIterator*)BreakIterator::createLineInstance(loc, status);
+               rbiterator = (BreakIterator*)BreakIterator::createLineInstance(loc, status);
                break;
             case UBRK_SENTENCE: // sentence
-               rbiterator = (RuleBasedBreakIterator*)BreakIterator::createSentenceInstance(loc, status);
+               rbiterator = (BreakIterator*)BreakIterator::createSentenceInstance(loc, status);
                break;
             case UBRK_WORD: // word
-               rbiterator = (RuleBasedBreakIterator*)BreakIterator::createWordInstance(loc, status);
+               rbiterator = (BreakIterator*)BreakIterator::createWordInstance(loc, status);
                break;
-            case UBRK_COUNT:
             default:
                throw StriException(MSG__INTERNAL_ERROR);
+            }
          }
          STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
-
-//         UnicodeString s = rbiterator->getRules();
-//         std::string s2;
-//         s.toUTF8String(s2);
-//         printf("%s\n", s2.c_str());
       }
 
       bool ignoreBoundary();
