@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' package for R.
- * Copyright (C) 2013-2016, Marek Gagolewski and Bartek Tartanus
+ * Copyright (c) 2013-2018, Marek Gagolewski and other contributors.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -52,6 +52,9 @@ StriContainerUTF8::StriContainerUTF8()
  * @param rstr R character vector
  * @param nrecycle extend length [vectorization]
  * @param shallowrecycle will \code{this->str} be ever modified?
+ *
+ * @version 1.0.6 (Marek Gagolewski, 2017-05-25)
+ *    #270 latin-1 is windows-1252 on Windows
  */
 StriContainerUTF8::StriContainerUTF8(SEXP rstr, R_len_t _nrecycle, bool _shallowrecycle)
 {
@@ -76,7 +79,12 @@ StriContainerUTF8::StriContainerUTF8(SEXP rstr, R_len_t _nrecycle, bool _shallow
    code to handle several important encodings algorithmically: US-ASCII,
    ISO-8859-1, UTF-7/8/16/32, SCSU, BOCU-1, CESU-8, and IMAP-mailbox-name */
    // for conversion from non-utf8/ascii native charsets:
+#if defined(_WIN32) || defined(_WIN64)
+   // #270: latin-1 is windows-1252 on Windows
+   StriUcnv ucnvLatin1("WINDOWS-1252");
+#else
    StriUcnv ucnvLatin1("ISO-8859-1");
+#endif
    StriUcnv ucnvNative(NULL);
    R_len_t outbufsize = -1;
    String8buf outbuf(0);
@@ -129,7 +137,7 @@ StriContainerUTF8::StriContainerUTF8(SEXP rstr, R_len_t _nrecycle, bool _shallow
             // calculate max string length
             R_len_t maxlen = LENGTH(curs);
             for (R_len_t z=i+1; z<nrstr; ++z) {
-               // start from the current string (this no need to re-encode for < i)
+               // start from the current string (there's no need to re-encode for < i)
                SEXP tmps = STRING_ELT(rstr, z);
                if ((tmps != NA_STRING)
                      && !(IS_ASCII(tmps) || IS_UTF8(tmps) || IS_BYTES(tmps))
