@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' package for R.
- * Copyright (c) 2013-2018, Marek Gagolewski and other contributors.
+ * Copyright (c) 2013-2019, Marek Gagolewski and other contributors.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -33,13 +33,33 @@
 #include "stri_stringi.h"
 #include <unicode/uloc.h>
 
+/**
+ * Prepare list argument
+ *
+ * @param x a list or NULL
+ * @param argname argument name (message formatting)
+ * @return a list
+ *
+ * @version 1.3.2 (Marek Gagolewski, 2019-02-21)
+ */
+SEXP stri_prepare_arg_list(SEXP x, const char* argname)
+{
+   if ((SEXP*)argname == (SEXP*)R_NilValue)
+      argname = "<noname>";
+
+   if (!isNull(x) && !Rf_isVectorList(x))
+      Rf_error(MSG__ARG_EXPECTED_LIST, argname); // error() allowed here
+
+   return x;
+}
+
 
 /**
  * Prepare list of raw vectors argument, single raw vector,
  * or character vector argument
  *
  * Useful when dealing with raw data, like in string encoding
- * conversion or detection. For use e.g. with StriContainerListRaw.
+ * conversion or detection. For use, e.g., with StriContainerListRaw.
  *
  * If the object cannot be coerced, then an error will be generated
  *
@@ -80,7 +100,7 @@ SEXP stri_prepare_arg_list_raw(SEXP x, const char* argname)
 /**
  * Prepare list of integer vectors or an integer vector argument
  *
- *  For use e.g. with StriContainerListInt.
+ *  For use, e.g., with StriContainerListInt.
  *
  * If the object cannot be coerced, then an error will be generated
  *
@@ -339,30 +359,35 @@ SEXP stri_prepare_arg_double(SEXP x, const char* argname)
  * @return numeric vector
  *
  * @version 0.5-1 (Marek Gagolewski, 2014-12-30)
+ * @version 1.1.6 (Marek Gagolewski, 2020-02-17) bugfix #370
  *
  */
 SEXP stri_prepare_arg_POSIXct(SEXP x, const char* argname)
 {
+   int num_protect = 0;
    if ((SEXP*)argname == (SEXP*)R_NilValue)
       argname = "<noname>";
 
    if (Rf_inherits(x, "POSIXlt") || Rf_inherits(x, "Date")) {
-      PROTECT(x = Rf_eval(Rf_lang2(Rf_install("as.POSIXct"), x), R_GlobalEnv));
+      SEXP tmp1;
+      PROTECT(tmp1 = Rf_lang2(Rf_install("as.POSIXct"), x));
+      PROTECT(x = Rf_eval(tmp1, R_GlobalEnv));
+      num_protect += 2;
    }
-   else
-      PROTECT(x);
 
    if (!Rf_inherits(x, "POSIXct")) {
       Rf_error(MSG__ARG_EXPECTED_POSIXct, argname);
    }
 
-   SEXP attrib_class, attrib_tzone;
-   PROTECT(attrib_class = Rf_getAttrib(x, Rf_ScalarString(Rf_mkChar("class"))));
-   PROTECT(attrib_tzone = Rf_getAttrib(x, Rf_ScalarString(Rf_mkChar("tzone"))));
+   SEXP attrib_class, attrib_tzone, robj_class, robj_tzone;
+   PROTECT(robj_class = Rf_ScalarString(Rf_mkChar("class")));
+   PROTECT(robj_tzone = Rf_ScalarString(Rf_mkChar("tzone")));
+   PROTECT(attrib_class = Rf_getAttrib(x, robj_class));
+   PROTECT(attrib_tzone = Rf_getAttrib(x, robj_tzone));
    PROTECT(x = stri_prepare_arg_double(x, argname));
-   Rf_setAttrib(x, Rf_ScalarString(Rf_mkChar("class")), attrib_class);
-   Rf_setAttrib(x, Rf_ScalarString(Rf_mkChar("tzone")), attrib_tzone);
-   UNPROTECT(4);
+   Rf_setAttrib(x, robj_class, attrib_class);
+   Rf_setAttrib(x, robj_tzone, attrib_tzone);
+   UNPROTECT(num_protect+5);
    return x;
 }
 
