@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' package for R.
- * Copyright (C) 2013-2016, Marek Gagolewski and Bartek Tartanus
+ * Copyright (c) 2013-2017, Marek Gagolewski and other contributors.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -134,7 +134,7 @@ SEXP stri_extract_all_boundaries(SEXP str, SEXP simplify, SEXP omit_no_match, SE
    StriBrkIterOptions opts_brkiter2(opts_brkiter, "line_break");
 
    STRI__ERROR_HANDLER_BEGIN(2)
-   R_len_t str_length = LENGTH(str);
+      R_len_t str_length = LENGTH(str);
    StriContainerUTF8_indexable str_cont(str, str_length);
    StriRuleBasedBreakIterator brkiter(opts_brkiter2);
 
@@ -169,22 +169,25 @@ SEXP stri_extract_all_boundaries(SEXP str, SEXP simplify, SEXP omit_no_match, SE
       for (R_len_t j = 0; iter != occurrences.end(); ++iter, ++j) {
          pair<R_len_t, R_len_t> curo = *iter;
          SET_STRING_ELT(cur_res, j,
-            Rf_mkCharLenCE(str_cur_s+curo.first, curo.second-curo.first, CE_UTF8));
+                        Rf_mkCharLenCE(str_cur_s+curo.first, curo.second-curo.first, CE_UTF8));
       }
       SET_VECTOR_ELT(ret, i, cur_res);
       STRI__UNPROTECT(1);
    }
 
-   if (LOGICAL(simplify)[0] == NA_LOGICAL) {
-      STRI__PROTECT(ret = stri_list2matrix(ret, Rf_ScalarLogical(TRUE),
-         stri__vector_NA_strings(1), Rf_ScalarInteger(0)))
-   }
-   else if (LOGICAL(simplify)[0]) {
-      STRI__PROTECT(ret = stri_list2matrix(ret, Rf_ScalarLogical(TRUE),
-         stri__vector_empty_strings(1), Rf_ScalarInteger(0)))
+   if (LOGICAL(simplify)[0] == NA_LOGICAL || LOGICAL(simplify)[0]) {
+      SEXP robj_TRUE, robj_zero, robj_na_strings, robj_empty_strings;
+      STRI__PROTECT(robj_TRUE = Rf_ScalarLogical(TRUE));
+      STRI__PROTECT(robj_zero = Rf_ScalarInteger(0));
+      STRI__PROTECT(robj_na_strings = stri__vector_NA_strings(1));
+      STRI__PROTECT(robj_empty_strings = stri__vector_empty_strings(1));
+      STRI__PROTECT(ret = stri_list2matrix(ret, robj_TRUE,
+                                           (LOGICAL(simplify)[0] == NA_LOGICAL)?robj_na_strings
+                                              :robj_empty_strings,
+                                               robj_zero));
    }
 
    STRI__UNPROTECT_ALL
-   return ret;
+      return ret;
    STRI__ERROR_HANDLER_END({/* no-op */})
 }
